powered by
strs_rjust right-justifies each element of a character vector in a field of a specified width. It is similar to Python's str.rjust() method.
strs_rjust
str.rjust()
strs_rjust(string, width, fillchar = " ")
A character vector of the same length as string, with each element right-justified in a field of the specified width.
string
A character vector where each element is a string to be right-justified.
The total width of the field in which the string is to be right-justified.
A character used for padding on the left.
Python str.rjust() documentation
strs_rjust("hello", 10) strs_rjust("world", 10, "*")
Run the code above in your browser using DataLab